[Zope3-checkins]
SVN: Zope3/trunk/src/zope/configuration/interfaces.py
Document the order optional argument for action()
Julien Anguenot
ja at nuxeo.com
Fri Jul 29 13:16:15 EDT 2005
Log message for revision 37552:
Document the order optional argument for action()
Changed:
U Zope3/trunk/src/zope/configuration/interfaces.py
-=-
Modified: Zope3/trunk/src/zope/configuration/interfaces.py
===================================================================
--- Zope3/trunk/src/zope/configuration/interfaces.py 2005-07-29 16:28:55 UTC (rev 37551)
+++ Zope3/trunk/src/zope/configuration/interfaces.py 2005-07-29 17:16:15 UTC (rev 37552)
@@ -74,16 +74,18 @@
is better than an unlimited number of conflict errors.
"""
- def action(self, discriminator, callable, args=(), kw={}):
+ def action(self, discriminator, callable, args=(), kw={}, order=0):
"""Record a configuration action
- The job of most directives is to compute actions for later processing.
- The action method is used to record those actions. The discriminator
- is used to to find actions that conflict. Actions conflict if they
- have the same discriminator. The exception to this is the
- special case of the discriminator with the value None. An
- actions with a discriminator of None never conflicts with
- other actions.
+ The job of most directives is to compute actions for later
+ processing. The action method is used to record those
+ actions. The discriminator is used to to find actions that
+ conflict. Actions conflict if they have the same
+ discriminator. The exception to this is the special case of
+ the discriminator with the value None. An actions with a
+ discriminator of None never conflicts with other actions. This
+ is possible to add an order argument to crudely control the
+ order of execution
"""
def provideFeature(name):
More information about the Zope3-Checkins
mailing list